California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 014 - AUTHORIZES BONDS TO CONTINUE FUNDING STEM CELL AND OTHER MEDICAL RESEARCH. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1429603 | NO ON PROPOSITION 14 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1433352 | ENOUGH IS ENOUGH, NO NEW TAXES! | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1422494 | YES ON 14: CALIFORNIANS FOR STEM CELL RESEARCH, TREATMENTS AND CURES | SUPPORT